import * as i0 from '@angular/core';
import { Component, Input, HostListener, EventEmitter, Output, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { BrowserModule } from '@angular/platform-browser';

const extensions = {
    "htm": "html",
    "html": "html",
    "ts": "typescript",
    "js": "javascript",
    "xhtml": "html",
    "html_vm": "html",
    "asp": "html",
    "jade": "pug",
    "pug": "pug",
    "md": "markdown",
    "markdown": "markdown",
    "rst": "markdown",
    "blink": "blink",
    "css": "css",
    "scss": "sass",
    "sass": "sass",
    "less": "less",
    "json": "json",
    "tsbuildinfo": "json",
    "json5": "json",
    "jsonl": "json",
    "ndjson": "json",
    "jinja": "jinja",
    "jinja2": "jinja",
    "j2": "jinja",
    "jinja-html": "jinja",
    "proto": "proto",
    "sublime-project": "sublime",
    "sublime-workspace": "sublime",
    "tw": "twine",
    "twee": "twine",
    "yml": "yaml",
    "yaml": "yaml",
    "yml.dist": "yaml",
    "yaml.dist": "yaml",
    "YAML-tmLanguage": "yaml",
    "xml": "xml",
    "plist": "xml",
    "xsd": "xml",
    "dtd": "xml",
    "xsl": "xml",
    "xslt": "xml",
    "resx": "xml",
    "iml": "xml",
    "xquery": "xml",
    "tmLanguage": "xml",
    "manifest": "xml",
    "project": "xml",
    "xml.dist": "xml",
    "xml.dist.sample": "xml",
    "dmn": "xml",
    "png": "image",
    "jpeg": "image",
    "jpg": "image",
    "gif": "image",
    "ico": "image",
    "tif": "image",
    "tiff": "image",
    "psd": "image",
    "psb": "image",
    "ami": "image",
    "apx": "image",
    "bmp": "image",
    "bpg": "image",
    "brk": "image",
    "cur": "image",
    "dds": "image",
    "dng": "image",
    "exr": "image",
    "fpx": "image",
    "gbr": "image",
    "img": "image",
    "jbig2": "image",
    "jb2": "image",
    "jng": "image",
    "jxr": "image",
    "pgf": "image",
    "pic": "image",
    "raw": "image",
    "webp": "image",
    "eps": "image",
    "afphoto": "image",
    "ase": "image",
    "aseprite": "image",
    "clip": "image",
    "cpt": "image",
    "heif": "image",
    "heic": "image",
    "kra": "image",
    "mdp": "image",
    "ora": "image",
    "pdn": "image",
    "reb": "image",
    "sai": "image",
    "tga": "image",
    "xcf": "image",
    "jfif": "image",
    "ppm": "image",
    "pbm": "image",
    "pgm": "image",
    "pnm": "image",
    "esx": "javascript",
    "mjs": "javascript",
    "jsx": "react",
    "tsx": "react_ts",
    "routing.ts": "routing",
    "routing.tsx": "routing",
    "routing.js": "routing",
    "routing.jsx": "routing",
    "routes.ts": "routing",
    "routes.tsx": "routing",
    "routes.js": "routing",
    "routes.jsx": "routing",
    "ini": "settings",
    "dlc": "settings",
    "dll": "settings",
    "config": "settings",
    "conf": "settings",
    "properties": "settings",
    "prop": "settings",
    "settings": "settings",
    "option": "settings",
    "props": "settings",
    "toml": "settings",
    "prefs": "settings",
    "sln.dotsettings": "settings",
    "sln.dotsettings.user": "settings",
    "cfg": "settings",
    "d.ts": "typescript-def",
    "marko": "markojs",
    "astro": "astro",
    "pdf": "pdf",
    "xlsx": "table",
    "xls": "table",
    "csv": "table",
    "tsv": "table",
    "vscodeignore": "vscode",
    "vsixmanifest": "vscode",
    "vsix": "vscode",
    "code-workplace": "vscode",
    "csproj": "visualstudio",
    "ruleset": "visualstudio",
    "sln": "visualstudio",
    "suo": "visualstudio",
    "vb": "visualstudio",
    "vbs": "visualstudio",
    "vcxitems": "visualstudio",
    "vcxitems.filters": "visualstudio",
    "vcxproj": "visualstudio",
    "vcxproj.filters": "visualstudio",
    "pdb": "database",
    "sql": "database",
    "pks": "database",
    "pkb": "database",
    "accdb": "database",
    "mdb": "database",
    "sqlite": "database",
    "sqlite3": "database",
    "pgsql": "database",
    "postgres": "database",
    "psql": "database",
    "db": "database",
    "db3": "database",
    "kql": "kusto",
    "cs": "csharp",
    "csx": "csharp",
    "qs": "qsharp",
    "zip": "zip",
    "tar": "zip",
    "gz": "zip",
    "xz": "zip",
    "br": "zip",
    "bzip2": "zip",
    "gzip": "zip",
    "brotli": "zip",
    "7z": "zip",
    "rar": "zip",
    "tgz": "zip",
    "vala": "vala",
    "zig": "zig",
    "exe": "exe",
    "msi": "exe",
    "dat": "hex",
    "bin": "hex",
    "hex": "hex",
    "java": "java",
    "jsp": "java",
    "jar": "jar",
    "class": "javaclass",
    "c": "c",
    "i": "c",
    "mi": "c",
    "h": "h",
    "cc": "cpp",
    "cpp": "cpp",
    "cxx": "cpp",
    "c++": "cpp",
    "cp": "cpp",
    "mm": "cpp",
    "mii": "cpp",
    "ii": "cpp",
    "hh": "hpp",
    "hpp": "hpp",
    "hxx": "hpp",
    "h++": "hpp",
    "hp": "hpp",
    "tcc": "hpp",
    "inl": "hpp",
    "go": "go",
    "py": "python",
    "pyc": "python-misc",
    "whl": "python-misc",
    "url": "url",
    "sh": "console",
    "ksh": "console",
    "csh": "console",
    "tcsh": "console",
    "zsh": "console",
    "bash": "console",
    "bat": "console",
    "cmd": "console",
    "awk": "console",
    "fish": "console",
    "exp": "console",
    "ps1": "powershell",
    "psm1": "powershell",
    "psd1": "powershell",
    "ps1xml": "powershell",
    "psc1": "powershell",
    "pssc": "powershell",
    "gradle": "gradle",
    "doc": "word",
    "docx": "word",
    "rtf": "word",
    "cer": "certificate",
    "cert": "certificate",
    "crt": "certificate",
    "pub": "key",
    "key": "key",
    "pem": "key",
    "asc": "key",
    "gpg": "key",
    "passwd": "key",
    "woff": "font",
    "woff2": "font",
    "ttf": "font",
    "eot": "font",
    "suit": "font",
    "otf": "font",
    "bmap": "font",
    "fnt": "font",
    "odttf": "font",
    "ttc": "font",
    "font": "font",
    "fonts": "font",
    "sui": "font",
    "ntf": "font",
    "mrf": "font",
    "lib": "lib",
    "bib": "lib",
    "rb": "ruby",
    "erb": "ruby",
    "fs": "fsharp",
    "fsx": "fsharp",
    "fsi": "fsharp",
    "fsproj": "fsharp",
    "swift": "swift",
    "ino": "arduino",
    "dockerignore": "docker",
    "dockerfile": "docker",
    "tex": "tex",
    "sty": "tex",
    "dtx": "tex",
    "ltx": "tex",
    "pptx": "powerpoint",
    "ppt": "powerpoint",
    "pptm": "powerpoint",
    "potx": "powerpoint",
    "potm": "powerpoint",
    "ppsx": "powerpoint",
    "ppsm": "powerpoint",
    "pps": "powerpoint",
    "ppam": "powerpoint",
    "ppa": "powerpoint",
    "webm": "video",
    "mkv": "video",
    "flv": "video",
    "vob": "video",
    "ogv": "video",
    "ogg": "video",
    "gifv": "video",
    "avi": "video",
    "mov": "video",
    "qt": "video",
    "wmv": "video",
    "yuv": "video",
    "rm": "video",
    "rmvb": "video",
    "mp4": "video",
    "m4v": "video",
    "mpg": "video",
    "mp2": "video",
    "mpeg": "video",
    "mpe": "video",
    "mpv": "video",
    "m2v": "video",
    "vdi": "virtual",
    "vbox": "virtual",
    "vbox-prev": "virtual",
    "ics": "email",
    "mp3": "audio",
    "flac": "audio",
    "m4a": "audio",
    "wma": "audio",
    "aiff": "audio",
    "wav": "audio",
    "coffee": "coffee",
    "cson": "coffee",
    "iced": "coffee",
    "txt": "document",
    "graphql": "graphql",
    "gql": "graphql",
    "rs": "rust",
    "raml": "raml",
    "xaml": "xaml",
    "hs": "haskell",
    "kt": "kotlin",
    "kts": "kotlin",
    "patch": "git",
    "lua": "lua",
    "clj": "clojure",
    "cljs": "clojure",
    "cljc": "clojure",
    "groovy": "groovy",
    "r": "r",
    "rmd": "r",
    "dart": "dart",
    "as": "actionscript",
    "mxml": "mxml",
    "ahk": "autohotkey",
    "swf": "flash",
    "swc": "swc",
    "cmake": "cmake",
    "asm": "assembly",
    "a51": "assembly",
    "inc": "assembly",
    "nasm": "assembly",
    "s": "assembly",
    "ms": "assembly",
    "agc": "assembly",
    "ags": "assembly",
    "aea": "assembly",
    "argus": "assembly",
    "mitigus": "assembly",
    "binsource": "assembly",
    "vue": "vue",
    "ml": "ocaml",
    "mli": "ocaml",
    "cmx": "ocaml",
    "odin": "odin",
    "js.map": "javascript-map",
    "mjs.map": "javascript-map",
    "cjs.map": "javascript-map",
    "css.map": "css-map",
    "lock": "lock",
    "hbs": "handlebars",
    "mustache": "handlebars",
    "pm": "perl",
    "raku": "perl",
    "hx": "haxe",
    "spec.ts": "test-ts",
    "e2e-spec.ts": "test-ts",
    "test.ts": "test-ts",
    "ts.snap": "test-ts",
    "spec.tsx": "test-jsx",
    "test.tsx": "test-jsx",
    "tsx.snap": "test-jsx",
    "spec.jsx": "test-jsx",
    "test.jsx": "test-jsx",
    "jsx.snap": "test-jsx",
    "spec.js": "test-js",
    "spec.cjs": "test-js",
    "spec.mjs": "test-js",
    "e2e-spec.js": "test-js",
    "e2e-spec.cjs": "test-js",
    "e2e-spec.mjs": "test-js",
    "test.js": "test-js",
    "test.cjs": "test-js",
    "test.mjs": "test-js",
    "js.snap": "test-js",
    "module.ts": "angular",
    "module.js": "angular",
    "ng-template": "angular",
    "component.ts": "angular-component",
    "component.js": "angular-component",
    "guard.ts": "angular-guard",
    "guard.js": "angular-guard",
    "service.ts": "angular-service",
    "service.js": "angular-service",
    "pipe.ts": "angular-pipe",
    "pipe.js": "angular-pipe",
    "filter.js": "angular-pipe",
    "directive.ts": "angular-directive",
    "directive.js": "angular-directive",
    "resolver.ts": "angular-resolver",
    "resolver.js": "angular-resolver",
    "pp": "puppet",
    "ex": "elixir",
    "exs": "elixir",
    "eex": "elixir",
    "leex": "elixir",
    "heex": "elixir",
    "ls": "livescript",
    "erl": "erlang",
    "twig": "twig",
    "jl": "julia",
    "elm": "elm",
    "pure": "purescript",
    "purs": "purescript",
    "tpl": "smarty",
    "styl": "stylus",
    "re": "reason",
    "rei": "reason",
    "cmj": "bucklescript",
    "merlin": "merlin",
    "vhd": "verilog",
    "sv": "verilog",
    "svh": "verilog",
    "nb": "mathematica",
    "wl": "wolframlanguage",
    "wls": "wolframlanguage",
    "njk": "nunjucks",
    "nunjucks": "nunjucks",
    "robot": "robot",
    "sol": "solidity",
    "au3": "autoit",
    "haml": "haml",
    "yang": "yang",
    "mjml": "mjml",
    "tf": "terraform",
    "tf.json": "terraform",
    "tfvars": "terraform",
    "tfstate": "terraform",
    "blade.php": "laravel",
    "inky.php": "laravel",
    "applescript": "applescript",
    "ipa": "applescript",
    "cake": "cake",
    "feature": "cucumber",
    "nim": "nim",
    "nimble": "nim",
    "apib": "apiblueprint",
    "apiblueprint": "apiblueprint",
    "riot": "riot",
    "tag": "riot",
    "vfl": "vfl",
    "kl": "kl",
    "pcss": "postcss",
    "sss": "postcss",
    "todo": "todo",
    "cfml": "coldfusion",
    "cfc": "coldfusion",
    "lucee": "coldfusion",
    "cfm": "coldfusion",
    "cabal": "cabal",
    "nix": "nix",
    "slim": "slim",
    "http": "http",
    "rest": "http",
    "rql": "restql",
    "restql": "restql",
    "kv": "kivy",
    "graphcool": "graphcool",
    "sbt": "sbt",
    "apk": "android",
    "smali": "android",
    "dex": "android",
    "env": "tune",
    "gitlab-ci.yml": "gitlab",
    "jenkinsfile": "jenkins",
    "jenkins": "jenkins",
    "fig": "figma",
    "cr": "crystal",
    "ecr": "crystal",
    "drone.yml": "drone",
    "cu": "cuda",
    "cuh": "cuda",
    "log": "log",
    "def": "dotjs",
    "dot": "dotjs",
    "jst": "dotjs",
    "ejs": "ejs",
    ".wakatime-project": "wakatime",
    "pde": "processing",
    "stories.js": "storybook",
    "stories.jsx": "storybook",
    "stories.mdx": "storybook",
    "story.js": "storybook",
    "story.jsx": "storybook",
    "stories.ts": "storybook",
    "stories.tsx": "storybook",
    "story.ts": "storybook",
    "story.tsx": "storybook",
    "stories.svelte": "storybook",
    "story.mdx": "storybook",
    "wpy": "wepy",
    "hcl": "hcl",
    "san": "san",
    "djt": "django",
    "red": "red",
    "fxp": "foxpro",
    "prg": "foxpro",
    "pot": "i18n",
    "po": "i18n",
    "mo": "i18n",
    "wat": "webassembly",
    "wasm": "webassembly",
    "ipynb": "jupyter",
    "d": "d",
    "mdx": "mdx",
    "bal": "ballerina",
    "balx": "ballerina",
    "rkt": "racket",
    "bzl": "bazel",
    "bazel": "bazel",
    "mint": "mint",
    "vm": "velocity",
    "fhtml": "velocity",
    "vtl": "velocity",
    "gd": "godot",
    "godot": "godot-assets",
    "tres": "godot-assets",
    "tscn": "godot-assets",
    "azure-pipelines.yml": "azure-pipelines",
    "azure-pipelines.yaml": "azure-pipelines",
    "azcli": "azure",
    "vagrantfile": "vagrant",
    "prisma": "prisma",
    "cshtml": "razor",
    "vbhtml": "razor",
    "abc": "abc",
    "ad": "asciidoc",
    "adoc": "asciidoc",
    "asciidoc": "asciidoc",
    "edge": "edge",
    "ss": "scheme",
    "scm": "scheme",
    "lisp": "lisp",
    "lsp": "lisp",
    "cl": "lisp",
    "fast": "lisp",
    "stl": "3d",
    "obj": "3d",
    "ac": "3d",
    "blend": "3d",
    "mesh": "3d",
    "mqo": "3d",
    "pmd": "3d",
    "pmx": "3d",
    "skp": "3d",
    "vac": "3d",
    "vdp": "3d",
    "vox": "3d",
    "svg": "svg",
    "svelte": "svelte",
    "vimrc": "vim",
    "gvimrc": "vim",
    "exrc": "vim",
    "vim": "vim",
    "viminfo": "vim",
    "moon": "moonscript",
    "prw": "advpl_prw",
    "prx": "advpl_prw",
    "ptm": "advpl_ptm",
    "tlpp": "advpl_tlpp",
    "ch": "advpl_include",
    "iso": "disc",
    "f": "fortran",
    "f77": "fortran",
    "f90": "fortran",
    "f95": "fortran",
    "f03": "fortran",
    "f08": "fortran",
    "tcl": "tcl",
    "liquid": "liquid",
    "p": "prolog",
    "pro": "prolog",
    "pl": "prolog",
    "coco": "coconut",
    "sketch": "sketch",
    "pwn": "pawn",
    "amx": "pawn",
    "4th": "forth",
    "fth": "forth",
    "frt": "forth",
    "iuml": "uml",
    "pu": "uml",
    "puml": "uml",
    "plantuml": "uml",
    "wsd": "uml",
    "wrap": "meson",
    "dhall": "dhall",
    "dhallb": "dhall",
    "sml": "sml",
    "mlton": "sml",
    "mlb": "sml",
    "sig": "sml",
    "fun": "sml",
    "cm": "sml",
    "lex": "sml",
    "use": "sml",
    "grm": "sml",
    "opam": "opam",
    "imba": "imba",
    "drawio": "drawio",
    "dio": "drawio",
    "pas": "pascal",
    "unity": "shaderlab",
    "sas": "sas",
    "sas7bdat": "sas",
    "sashdat": "sas",
    "astore": "sas",
    "ast": "sas",
    "sast": "sas",
    "nupkg": "nuget",
    "command": "command",
    "dsc": "denizenscript",
    "code-search": "search",
    "mcfunction": "minecraft",
    "mcmeta": "minecraft",
    "mcr": "minecraft",
    "mca": "minecraft",
    "mcgame": "minecraft",
    "mclevel": "minecraft",
    "mcworld": "minecraft",
    "mine": "minecraft",
    "mus": "minecraft",
    "res": "rescript",
    "resi": "rescript",
    "b": "brainfuck",
    "bf": "brainfuck",
    "bicep": "bicep",
    "cob": "cobol",
    "cbl": "cobol",
    "gr": "grain",
    "lol": "lolcode",
    "idr": "idris",
    "ibc": "idris",
    "pipeline": "pipeline",
    "rego": "opa",
    "windi": "windicss",
    "scala": "scala",
    "sc": "scala",
    "ly": "lilypond",
    "v": "vlang",
    "pgn": "chess",
    "fen": "chess",
    "gmi": "gemini",
    "gemini": "gemini",
    "tsconfig.json": "tsconfig",
    "tauri": "tauri",
    "jsconfig.json": "jsconfig",
    "ada": "ada",
    "adb": "ada",
    "ads": "ada",
    "ali": "ada",
    "horusec-config.json": "horusec",
    "coarc": "coala",
    "coafile": "coala",
    "bubble": "dinophp",
    "html.bubble": "dinophp",
    "php.bubble": "dinophp",
    "tl": "teal",
    "template": "template",
    "sy": "siyuan",
    "ndst.yml": "ndst",
    "ndst.yaml": "ndst",
    "ndst.json": "ndst",
    "tobi": "tobi"
};

const files = {
    ".pug-lintrc": "pug",
    ".pug-lintrc.js": "pug",
    ".pug-lintrc.json": "pug",
    ".jscsrc": "json",
    ".jshintrc": "json",
    "composer.lock": "json",
    ".jsbeautifyrc": "json",
    ".esformatter": "json",
    "cdp.pid": "json",
    ".lintstagedrc": "json",
    "playwright.config.js": "playwright",
    "playwright.config.ts": "playwright",
    ".htaccess": "xml",
    "router.js": "routing",
    "router.jsx": "routing",
    "router.ts": "routing",
    "router.tsx": "routing",
    "routes.js": "routing",
    "routes.jsx": "routing",
    "routes.ts": "routing",
    "routes.tsx": "routing",
    ".jshintignore": "settings",
    ".buildignore": "settings",
    ".mrconfig": "settings",
    ".yardopts": "settings",
    "manifest.mf": "settings",
    ".clang-format": "settings",
    ".clang-tidy": "settings",
    "astro.config.js": "astro",
    "astro.config.mjs": "astro",
    "astro.config.cjs": "astro",
    "go.mod": "go-mod",
    "go.sum": "go-mod",
    "requirements.txt": "python-misc",
    "pipfile": "python-misc",
    ".python-version": "python-misc",
    "manifest.in": "python-misc",
    "pylintrc": "python-misc",
    ".pylintrc": "python-misc",
    "pre-commit": "console",
    "pre-push": "console",
    "post-merge": "console",
    "gradle.properties": "gradle",
    "gradlew": "gradle",
    "gradle-wrapper.properties": "gradle",
    "copying": "certificate",
    "copying.md": "certificate",
    "copying.txt": "certificate",
    "copyright": "certificate",
    "copyright.txt": "certificate",
    "copyright.md": "certificate",
    "license": "certificate",
    "license.md": "certificate",
    "license.txt": "certificate",
    "licence": "certificate",
    "licence.md": "certificate",
    "licence.txt": "certificate",
    ".htpasswd": "key",
    "gemfile": "gemfile",
    ".rubocop.yml": "rubocop",
    ".rubocop-todo.yml": "rubocop",
    ".rubocop_todo.yml": "rubocop",
    "dockerfile": "docker",
    "dockerfile.prod": "docker",
    "dockerfile.production": "docker",
    "dockerfile.alpha": "docker",
    "dockerfile.beta": "docker",
    "dockerfile.stage": "docker",
    "dockerfile.staging": "docker",
    "dockerfile.dev": "docker",
    "dockerfile.development": "docker",
    "dockerfile.local": "docker",
    "dockerfile.test": "docker",
    "dockerfile.testing": "docker",
    "dockerfile.ci": "docker",
    "dockerfile.web": "docker",
    "dockerfile.worker": "docker",
    "docker-compose.yml": "docker",
    "docker-compose.override.yml": "docker",
    "docker-compose.prod.yml": "docker",
    "docker-compose.production.yml": "docker",
    "docker-compose.alpha.yml": "docker",
    "docker-compose.beta.yml": "docker",
    "docker-compose.stage.yml": "docker",
    "docker-compose.staging.yml": "docker",
    "docker-compose.dev.yml": "docker",
    "docker-compose.development.yml": "docker",
    "docker-compose.local.yml": "docker",
    "docker-compose.test.yml": "docker",
    "docker-compose.testing.yml": "docker",
    "docker-compose.ci.yml": "docker",
    "docker-compose.web.yml": "docker",
    "docker-compose.worker.yml": "docker",
    "docker-compose.yaml": "docker",
    "docker-compose.override.yaml": "docker",
    "docker-compose.prod.yaml": "docker",
    "docker-compose.production.yaml": "docker",
    "docker-compose.alpha.yaml": "docker",
    "docker-compose.beta.yaml": "docker",
    "docker-compose.stage.yaml": "docker",
    "docker-compose.staging.yaml": "docker",
    "docker-compose.dev.yaml": "docker",
    "docker-compose.development.yaml": "docker",
    "docker-compose.local.yaml": "docker",
    "docker-compose.test.yaml": "docker",
    "docker-compose.testing.yaml": "docker",
    "docker-compose.ci.yaml": "docker",
    "docker-compose.web.yaml": "docker",
    "docker-compose.worker.yaml": "docker",
    ".mailmap": "email",
    ".graphqlconfig": "graphql",
    ".graphqlrc": "graphql",
    ".graphqlrc.json": "graphql",
    ".graphqlrc.js": "graphql",
    ".graphqlrc.ts": "graphql",
    ".graphqlrc.toml": "graphql",
    ".graphqlrc.yaml": "graphql",
    ".graphqlrc.yml": "graphql",
    "graphql.config.json": "graphql",
    "graphql.config.js": "graphql",
    "graphql.config.ts": "graphql",
    "graphql.config.toml": "graphql",
    "graphql.config.yaml": "graphql",
    "graphql.config.yml": "graphql",
    ".gitignore": "git",
    ".gitignore_global": "git",
    ".gitconfig": "git",
    ".gitattributes": "git",
    ".gitmodules": "git",
    ".gitkeep": "git",
    ".gitinclude": "git",
    "git-history": "git",
    ".luacheckrc": "lua",
    ".Rhistory": "r",
    ".pubignore": "dart",
    "cmakelists.txt": "cmake",
    "cmakecache.txt": "cmake",
    "vue.config.js": "vue-config",
    "vue.config.ts": "vue-config",
    "vetur.config.js": "vue-config",
    "vetur.config.ts": "vue-config",
    "nuxt.config.js": "nuxt",
    "nuxt.config.ts": "nuxt",
    "security.md": "lock",
    "security.txt": "lock",
    "security": "lock",
    "angular-cli.json": "angular",
    ".angular-cli.json": "angular",
    "angular.json": "angular",
    ".mjmlconfig": "mjml",
    "vercel.json": "vercel",
    ".vercelignore": "vercel",
    "now.json": "vercel",
    ".nowignore": "vercel",
    "next.config.js": "next",
    "next.config.ts": "next",
    "next.config.mjs": "next",
    "remix.config.js": "remix",
    "remix.config.ts": "remix",
    "artisan": "laravel",
    ".vfl": "vfl",
    ".kl": "kl",
    "postcss.config.js": "postcss",
    "postcss.config.cjs": "postcss",
    ".postcssrc.js": "postcss",
    ".postcssrc": "postcss",
    ".postcssrc.json": "postcss",
    ".postcssrc.yml": "postcss",
    "posthtml.config.js": "posthtml",
    ".posthtmlrc.js": "posthtml",
    ".posthtmlrc": "posthtml",
    ".posthtmlrc.json": "posthtml",
    ".posthtmlrc.yml": "posthtml",
    "cabal.project": "cabal",
    "cabal.project.freeze": "cabal",
    "cabal.project.local": "cabal",
    "CNAME": "http",
    "project.graphcool": "graphcool",
    "webpack.js": "webpack",
    "webpack.cjs": "webpack",
    "webpack.ts": "webpack",
    "webpack.base.js": "webpack",
    "webpack.base.cjs": "webpack",
    "webpack.base.ts": "webpack",
    "webpack.config.js": "webpack",
    "webpack.config.cjs": "webpack",
    "webpack.config.ts": "webpack",
    "webpack.common.js": "webpack",
    "webpack.common.cjs": "webpack",
    "webpack.common.ts": "webpack",
    "webpack.config.common.js": "webpack",
    "webpack.config.common.cjs": "webpack",
    "webpack.config.common.ts": "webpack",
    "webpack.config.common.babel.js": "webpack",
    "webpack.config.common.babel.ts": "webpack",
    "webpack.dev.js": "webpack",
    "webpack.dev.cjs": "webpack",
    "webpack.dev.ts": "webpack",
    "webpack.development.js": "webpack",
    "webpack.development.cjs": "webpack",
    "webpack.development.ts": "webpack",
    "webpack.config.dev.js": "webpack",
    "webpack.config.dev.cjs": "webpack",
    "webpack.config.dev.ts": "webpack",
    "webpack.config.dev.babel.js": "webpack",
    "webpack.config.dev.babel.ts": "webpack",
    "webpack.mix.js": "webpack",
    "webpack.mix.cjs": "webpack",
    "webpack.prod.js": "webpack",
    "webpack.prod.cjs": "webpack",
    "webpack.prod.config.js": "webpack",
    "webpack.prod.config.cjs": "webpack",
    "webpack.prod.ts": "webpack",
    "webpack.production.js": "webpack",
    "webpack.production.cjs": "webpack",
    "webpack.production.ts": "webpack",
    "webpack.server.js": "webpack",
    "webpack.server.cjs": "webpack",
    "webpack.server.ts": "webpack",
    "webpack.client.js": "webpack",
    "webpack.client.cjs": "webpack",
    "webpack.client.ts": "webpack",
    "webpack.config.server.js": "webpack",
    "webpack.config.server.cjs": "webpack",
    "webpack.config.server.ts": "webpack",
    "webpack.config.client.js": "webpack",
    "webpack.config.client.cjs": "webpack",
    "webpack.config.client.ts": "webpack",
    "webpack.config.production.babel.js": "webpack",
    "webpack.config.production.babel.ts": "webpack",
    "webpack.config.prod.babel.js": "webpack",
    "webpack.config.prod.babel.cjs": "webpack",
    "webpack.config.prod.babel.ts": "webpack",
    "webpack.config.prod.js": "webpack",
    "webpack.config.prod.cjs": "webpack",
    "webpack.config.prod.ts": "webpack",
    "webpack.config.production.js": "webpack",
    "webpack.config.production.cjs": "webpack",
    "webpack.config.production.ts": "webpack",
    "webpack.config.staging.js": "webpack",
    "webpack.config.staging.cjs": "webpack",
    "webpack.config.staging.ts": "webpack",
    "webpack.config.babel.js": "webpack",
    "webpack.config.babel.ts": "webpack",
    "webpack.config.base.babel.js": "webpack",
    "webpack.config.base.babel.ts": "webpack",
    "webpack.config.base.js": "webpack",
    "webpack.config.base.cjs": "webpack",
    "webpack.config.base.ts": "webpack",
    "webpack.config.staging.babel.js": "webpack",
    "webpack.config.staging.babel.ts": "webpack",
    "webpack.config.coffee": "webpack",
    "webpack.config.test.js": "webpack",
    "webpack.config.test.cjs": "webpack",
    "webpack.config.test.ts": "webpack",
    "webpack.config.vendor.js": "webpack",
    "webpack.config.vendor.cjs": "webpack",
    "webpack.config.vendor.ts": "webpack",
    "webpack.config.vendor.production.js": "webpack",
    "webpack.config.vendor.production.cjs": "webpack",
    "webpack.config.vendor.production.ts": "webpack",
    "webpack.test.js": "webpack",
    "webpack.test.cjs": "webpack",
    "webpack.test.ts": "webpack",
    "webpack.dist.js": "webpack",
    "webpack.dist.cjs": "webpack",
    "webpack.dist.ts": "webpack",
    "webpackfile.js": "webpack",
    "webpackfile.cjs": "webpack",
    "webpackfile.ts": "webpack",
    "ionic.config.json": "ionic",
    ".io-config.json": "ionic",
    "gulpfile.js": "gulp",
    "gulpfile.mjs": "gulp",
    "gulpfile.ts": "gulp",
    "gulpfile.babel.js": "gulp",
    "package.json": "nodejs",
    "package-lock.json": "nodejs",
    ".nvmrc": "nodejs",
    ".esmrc": "nodejs",
    ".node-version": "nodejs",
    ".npmignore": "npm",
    ".npmrc": "npm",
    ".yarnrc": "yarn",
    "yarn.lock": "yarn",
    ".yarnclean": "yarn",
    ".yarn-integrity": "yarn",
    "yarn-error.log": "yarn",
    ".yarnrc.yml": "yarn",
    ".yarnrc.yaml": "yarn",
    "androidmanifest.xml": "android",
    ".env.defaults": "tune",
    ".env.example": "tune",
    ".env.sample": "tune",
    ".env.template": "tune",
    ".env.schema": "tune",
    ".env.local": "tune",
    ".env.dev": "tune",
    ".env.development": "tune",
    ".env.qa": "tune",
    ".env.dist": "tune",
    ".env.prod": "tune",
    ".env.production": "tune",
    ".env.stage": "tune",
    ".env.staging": "tune",
    ".env.preview": "tune",
    ".env.test": "tune",
    ".env.testing": "tune",
    ".env.development.local": "tune",
    ".env.qa.local": "tune",
    ".env.production.local": "tune",
    ".env.staging.local": "tune",
    ".env.test.local": "tune",
    ".babelrc": "babel",
    ".babelrc.cjs": "babel",
    ".babelrc.js": "babel",
    ".babelrc.mjs": "babel",
    ".babelrc.json": "babel",
    "babel.config.cjs": "babel",
    "babel.config.js": "babel",
    "babel.config.mjs": "babel",
    "babel.config.json": "babel",
    "babel-transform.js": "babel",
    ".babel-plugin-macrosrc": "babel",
    ".babel-plugin-macrosrc.json": "babel",
    ".babel-plugin-macrosrc.yaml": "babel",
    ".babel-plugin-macrosrc.yml": "babel",
    ".babel-plugin-macrosrc.js": "babel",
    "babel-plugin-macros.config.js": "babel",
    "blitz.config.js": "blitz",
    "blitz.config.ts": "blitz",
    ".blitz.config.compiled.js": "blitz",
    "contributing.md": "contributing",
    "readme.md": "readme",
    "readme.txt": "readme",
    "readme": "readme",
    "changelog": "changelog",
    "changelog.md": "changelog",
    "changelog.txt": "changelog",
    "changes": "changelog",
    "changes.md": "changelog",
    "changes.txt": "changelog",
    "credits": "credits",
    "credits.txt": "credits",
    "credits.md": "credits",
    "authors": "authors",
    "authors.md": "authors",
    "authors.txt": "authors",
    ".flowconfig": "flow",
    "favicon.ico": "favicon",
    "karma.conf.js": "karma",
    "karma.conf.ts": "karma",
    "karma.conf.coffee": "karma",
    "karma.config.js": "karma",
    "karma.config.ts": "karma",
    "karma-main.js": "karma",
    "karma-main.ts": "karma",
    ".bithoundrc": "bithound",
    "svgo.config.js": "svgo",
    ".appveyor.yml": "appveyor",
    "appveyor.yml": "appveyor",
    ".travis.yml": "travis",
    ".codecov.yml": "codecov",
    "codecov.yml": "codecov",
    "protractor.conf.js": "protractor",
    "protractor.conf.ts": "protractor",
    "protractor.conf.coffee": "protractor",
    "protractor.config.js": "protractor",
    "protractor.config.ts": "protractor",
    "fuse.js": "fusebox",
    "procfile": "heroku",
    "procfile.windows": "heroku",
    ".editorconfig": "editorconfig",
    ".bowerrc": "bower",
    "bower.json": "bower",
    ".eslintrc.js": "eslint",
    ".eslintrc.cjs": "eslint",
    ".eslintrc.yaml": "eslint",
    ".eslintrc.yml": "eslint",
    ".eslintrc.json": "eslint",
    ".eslintrc-md.js": "eslint",
    ".eslintrc-jsdoc.js": "eslint",
    ".eslintrc": "eslint",
    ".eslintignore": "eslint",
    ".eslintcache": "eslint",
    "code_of_conduct.md": "conduct",
    "code_of_conduct.txt": "conduct",
    ".watchmanconfig": "watchman",
    "aurelia.json": "aurelia",
    "mocha.opts": "mocha",
    ".mocharc.yml": "mocha",
    ".mocharc.yaml": "mocha",
    ".mocharc.js": "mocha",
    ".mocharc.json": "mocha",
    ".mocharc.jsonc": "mocha",
    "jenkinsfile": "jenkins",
    "firebase.json": "firebase",
    ".firebaserc": "firebase",
    "firestore.rules": "firebase",
    "firestore.indexes.json": "firebase",
    "rollup.config.js": "rollup",
    "rollup.config.ts": "rollup",
    "rollup-config.js": "rollup",
    "rollup-config.ts": "rollup",
    "rollup.config.common.js": "rollup",
    "rollup.config.common.ts": "rollup",
    "rollup.config.base.js": "rollup",
    "rollup.config.base.ts": "rollup",
    "rollup.config.prod.js": "rollup",
    "rollup.config.prod.ts": "rollup",
    "rollup.config.dev.js": "rollup",
    "rollup.config.dev.ts": "rollup",
    "rollup.config.prod.vendor.js": "rollup",
    "rollup.config.prod.vendor.ts": "rollup",
    ".hhconfig": "hack",
    ".stylelintrc": "stylelint",
    "stylelint.config.js": "stylelint",
    "stylelint.config.cjs": "stylelint",
    ".stylelintrc.json": "stylelint",
    ".stylelintrc.yaml": "stylelint",
    ".stylelintrc.yml": "stylelint",
    ".stylelintrc.js": "stylelint",
    ".stylelintrc.cjs": "stylelint",
    ".stylelintignore": "stylelint",
    ".codeclimate.yml": "code-climate",
    ".prettierrc": "prettier",
    "prettier.config.js": "prettier",
    "prettier.config.cjs": "prettier",
    ".prettierrc.js": "prettier",
    ".prettierrc.cjs": "prettier",
    ".prettierrc.json": "prettier",
    ".prettierrc.json5": "prettier",
    ".prettierrc.yaml": "prettier",
    ".prettierrc.yml": "prettier",
    ".prettierignore": "prettier",
    ".prettierrc.toml": "prettier",
    ".renovaterc": "renovate",
    ".renovaterc.json": "renovate",
    "renovate-config.json": "renovate",
    "renovate.json": "renovate",
    "renovate.json5": "renovate",
    "apollo.config.js": "apollo",
    "nodemon.json": "nodemon",
    "nodemon-debug.json": "nodemon",
    ".hintrc": "webhint",
    "browserslist": "browserlist",
    ".browserslistrc": "browserlist",
    ".snyk": "snyk",
    ".drone.yml": "drone",
    ".sequelizerc": "sequelize",
    "gatsby.config.js": "gatsby",
    "gatsby-config.js": "gatsby",
    "gatsby-node.js": "gatsby",
    "gatsby-browser.js": "gatsby",
    "gatsby-ssr.js": "gatsby",
    ".wakatime-project": "wakatime",
    "circle.yml": "circleci",
    ".cfignore": "cloudfoundry",
    "gruntfile.js": "grunt",
    "gruntfile.ts": "grunt",
    "gruntfile.coffee": "grunt",
    "gruntfile.babel.js": "grunt",
    "gruntfile.babel.ts": "grunt",
    "gruntfile.babel.coffee": "grunt",
    "jest.config.js": "jest",
    "jest.config.ts": "jest",
    "jest.config.cjs": "jest",
    "jest.config.mjs": "jest",
    "jest.config.json": "jest",
    "jest.e2e.config.js": "jest",
    "jest.e2e.config.ts": "jest",
    "jest.e2e.config.cjs": "jest",
    "jest.e2e.config.mjs": "jest",
    "jest.e2e.config.json": "jest",
    "jest.e2e.json": "jest",
    "jest-unit.config.js": "jest",
    "jest-e2e.config.js": "jest",
    "jest-e2e.config.ts": "jest",
    "jest-e2e.config.cjs": "jest",
    "jest-e2e.config.mjs": "jest",
    "jest-e2e.config.json": "jest",
    "jest-e2e.json": "jest",
    "jest-github-actions-reporter.js": "jest",
    "jest.setup.js": "jest",
    "jest.setup.ts": "jest",
    "jest.json": "jest",
    ".jestrc": "jest",
    ".jestrc.js": "jest",
    ".jestrc.json": "jest",
    "jest.teardown.js": "jest",
    "fastfile": "fastlane",
    "appfile": "fastlane",
    ".helmignore": "helm",
    "wallaby.js": "wallaby",
    "wallaby.conf.js": "wallaby",
    "stencil.config.js": "stencil",
    "stencil.config.ts": "stencil",
    "makefile": "makefile",
    ".releaserc": "semantic-release",
    ".releaserc.yaml": "semantic-release",
    ".releaserc.yml": "semantic-release",
    ".releaserc.json": "semantic-release",
    ".releaserc.js": "semantic-release",
    "release.config.js": "semantic-release",
    "bitbucket-pipelines.yaml": "bitbucket",
    "bitbucket-pipelines.yml": "bitbucket",
    ".bazelignore": "bazel",
    ".bazelrc": "bazel",
    ".bazelversion": "bazel",
    "azure-pipelines.yml": "azure-pipelines",
    "azure-pipelines.yaml": "azure-pipelines",
    "vagrantfile": "vagrant",
    "prisma.yml": "prisma",
    ".nycrc": "istanbul",
    ".nycrc.json": "istanbul",
    "tailwind.js": "tailwindcss",
    "tailwind.ts": "tailwindcss",
    "tailwind.config.js": "tailwindcss",
    "tailwind.config.ts": "tailwindcss",
    "tailwind.config.cjs": "tailwindcss",
    "buildkite.yml": "buildkite",
    "buildkite.yaml": "buildkite",
    "netlify.json": "netlify",
    "netlify.yml": "netlify",
    "netlify.yaml": "netlify",
    "netlify.toml": "netlify",
    "svelte.config.js": "svelte",
    "svelte.config.cjs": "svelte",
    "nest-cli.json": "nest",
    ".nest-cli.json": "nest",
    "nestconfig.json": "nest",
    ".nestconfig.json": "nest",
    ".percy.yml": "percy",
    ".gitpod.yml": "gitpod",
    "codeowners": "codeowners",
    ".gcloudignore": "gcp",
    ".huskyrc": "husky",
    "husky.config.js": "husky",
    ".huskyrc.json": "husky",
    ".huskyrc.js": "husky",
    ".huskyrc.yaml": "husky",
    ".huskyrc.yml": "husky",
    "tiltfile": "tilt",
    "capacitor.config.json": "capacitor",
    ".adonisrc.json": "adonis",
    "ace": "adonis",
    "meson.build": "meson",
    "meson_options.txt": "meson",
    ".commitlintrc": "commitlint",
    ".commitlintrc.js": "commitlint",
    "commitlint.config.js": "commitlint",
    ".commitlintrc.json": "commitlint",
    ".commitlint.yaml": "commitlint",
    ".commitlint.yml": "commitlint",
    ".commitlintrc.yaml": "commitlint",
    ".commitlintrc.yml": "commitlint",
    "commitlint.config.cjs": "commitlint",
    "commitlint.config.ts": "commitlint",
    ".commitlintrc.ts": "commitlint",
    ".commitlintrc.cjs": "commitlint",
    ".buckconfig": "buck",
    "nx.json": "nrwl",
    ".nxignore": "nrwl",
    "dune": "dune",
    "dune-project": "dune",
    "dune-workspace": "dune",
    "dune-workspace.dev": "dune",
    "roadmap.md": "roadmap",
    "roadmap.txt": "roadmap",
    "timeline.md": "roadmap",
    "timeline.txt": "roadmap",
    "milestones.md": "roadmap",
    "milestones.txt": "roadmap",
    "nuget.config": "nuget",
    ".nuspec": "nuget",
    "nuget.exe": "nuget",
    "stryker.conf.js": "stryker",
    "stryker.conf.json": "stryker",
    ".modernizrrc": "modernizr",
    ".modernizrrc.js": "modernizr",
    ".modernizrrc.json": "modernizr",
    ".slugignore": "slug",
    "stitches.config.js": "stitches",
    "stitches.config.ts": "stitches",
    "nginx.conf": "nginx",
    ".replit": "replit",
    "snowpack.config.cjs": "snowpack",
    "snowpack.config.js": "snowpack",
    "snowpack.config.mjs": "snowpack",
    "snowpack.deps.json": "snowpack",
    "snowpack.config.ts": "snowpack",
    "snowpack.config.json": "snowpack",
    "quasar.conf.js": "quasar",
    "dependabot.yml": "dependabot",
    "vite.config.js": "vite",
    "vite.config.mjs": "vite",
    "vite.config.cjs": "vite",
    "vite.config.ts": "vite",
    "lerna.json": "lerna",
    "windi.config.js": "windicss",
    "windi.config.ts": "windicss",
    "windi.config.cjs": "windicss",
    "windi.config.json": "windicss",
    ".textlintrc": "textlint",
    "vpkg.json": "vlang",
    "v.mod": "vlang",
    ".sentryclirc": "sentry",
    ".phpunit.result.cache": "phpunit",
    ".phpunit-watcher.yml": "phpunit",
    "phpunit.xml": "phpunit",
    "phpunit.xml.dist": "phpunit",
    "phpunit-watcher.yml": "phpunit",
    "phpunit-watcher.yml.dist": "phpunit",
    ".php_cs": "php-cs-fixer",
    ".php_cs.dist": "php-cs-fixer",
    ".php_cs.php": "php-cs-fixer",
    ".php_cs.dist.php": "php-cs-fixer",
    ".php-cs-fixer.php": "php-cs-fixer",
    ".php-cs-fixer.dist.php": "php-cs-fixer",
    "robots.txt": "robots",
    "tsconfig.json": "tsconfig",
    "tsconfig.app.json": "tsconfig",
    "tsconfig.editor.json": "tsconfig",
    "tsconfig.spec.json": "tsconfig",
    "tsconfig.base.json": "tsconfig",
    "tsconfig.build.json": "tsconfig",
    "tsconfig.eslint.json": "tsconfig",
    "tsconfig.lib.json": "tsconfig",
    "tauri.config.json": "tauri",
    "tauri.linux.conf.json": "tauri",
    "tauri.windows.conf.json": "tauri",
    "tauri.macos.conf.json": "tauri",
    "jsconfig.json": "jsconfig",
    "maven.config": "maven",
    "jvm.config": "maven",
    "serverless.yml": "serverless",
    ".ember-cli": "ember",
    ".ember-cli.js": "ember",
    "ember-cli-builds.js": "ember",
    "horusec-config.json": "horusec",
    ".astylerc": "astyle",
    ".lighthouserc.js": "lighthouse",
    "lighthouserc.js": "lighthouse",
    ".lighthouserc.json": "lighthouse",
    "lighthouserc.json": "lighthouse",
    ".lighthouserc.yml": "lighthouse",
    "lighthouserc.yml": "lighthouse",
    ".lighthouserc.yaml": "lighthouse",
    "lighthouserc.yaml": "lighthouse",
    ".svgrrc": "svgr",
    "svgr.config.js": "svgr",
    ".svgrrc.js": "svgr",
    ".svgrrc.yaml": "svgr",
    ".svgrrc.yml": "svgr",
    ".svgrrc.json": "svgr",
    "rome.json": "rome",
    "cypress.json": "cypress",
    "cypress.env.json": "cypress",
    ".tobimake": "tobimake"
};

const folders = {
    "src": "folder-src",
    "source": "folder-src",
    "sources": "folder-src",
    "code": "folder-src",
    "dist": "folder-dist",
    "out": "folder-dist",
    "build": "folder-dist",
    "release": "folder-dist",
    "bin": "folder-dist",
    "css": "folder-css",
    "stylesheet": "folder-css",
    "stylesheets": "folder-css",
    "style": "folder-css",
    "styles": "folder-css",
    "sass": "folder-sass",
    "_sass": "folder-sass",
    "scss": "folder-sass",
    "_scss": "folder-sass",
    "images": "folder-images",
    "image": "folder-images",
    "img": "folder-images",
    "icons": "folder-images",
    "icon": "folder-images",
    "ico": "folder-images",
    "screenshot": "folder-images",
    "screenshots": "folder-images",
    "picture": "folder-images",
    "pictures": "folder-images",
    "script": "folder-scripts",
    "scripts": "folder-scripts",
    "node_modules": "folder-node",
    "js": "folder-javascript",
    "javascript": "folder-javascript",
    "javascripts": "folder-javascript",
    "json": "folder-json",
    "font": "folder-font",
    "fonts": "folder-font",
    "bower_components": "folder-bower",
    "test": "folder-test",
    "tests": "folder-test",
    "testing": "folder-test",
    "__tests__": "folder-test",
    "__snapshots__": "folder-test",
    "__mocks__": "folder-test",
    "__test__": "folder-test",
    "spec": "folder-test",
    "specs": "folder-test",
    "jinja": "folder-jinja",
    "jinja2": "folder-jinja",
    "j2": "folder-jinja",
    "markdown": "folder-markdown",
    "md": "folder-markdown",
    "php": "folder-php",
    "phpmailer": "folder-phpmailer",
    "sublime": "folder-sublime",
    "doc": "folder-docs",
    "docs": "folder-docs",
    "document": "folder-docs",
    "documents": "folder-docs",
    "documentation": "folder-docs",
    "post": "folder-docs",
    "posts": "folder-docs",
    "article": "folder-docs",
    "articles": "folder-docs",
    ".git": "folder-git",
    "patches": "folder-git",
    "githooks": "folder-git",
    ".githooks": "folder-git",
    "submodules": "folder-git",
    ".submodules": "folder-git",
    ".github": "folder-github",
    ".gitlab": "folder-gitlab",
    ".vscode": "folder-vscode",
    ".vscode-test": "folder-vscode",
    "view": "folder-views",
    "views": "folder-views",
    "screen": "folder-views",
    "screens": "folder-views",
    "page": "folder-views",
    "pages": "folder-views",
    "html": "folder-views",
    "vue": "folder-vue",
    ".vuepress": "folder-vuepress",
    ".expo": "folder-expo",
    ".expo-shared": "folder-expo",
    "config": "folder-config",
    "configs": "folder-config",
    "configuration": "folder-config",
    "configurations": "folder-config",
    "setting": "folder-config",
    ".setting": "folder-config",
    "settings": "folder-config",
    ".settings": "folder-config",
    "META-INF": "folder-config",
    "i18n": "folder-i18n",
    "internationalization": "folder-i18n",
    "lang": "folder-i18n",
    "language": "folder-i18n",
    "languages": "folder-i18n",
    "locale": "folder-i18n",
    "locales": "folder-i18n",
    "l10n": "folder-i18n",
    "localization": "folder-i18n",
    "translation": "folder-i18n",
    "translate": "folder-i18n",
    "translations": "folder-i18n",
    ".tx": "folder-i18n",
    "components": "folder-components",
    "widget": "folder-components",
    "widgets": "folder-components",
    "aurelia_project": "folder-aurelia",
    "resource": "folder-resource",
    "resources": "folder-resource",
    "res": "folder-resource",
    "asset": "folder-resource",
    "assets": "folder-resource",
    "static": "folder-resource",
    "report": "folder-resource",
    "reports": "folder-resource",
    "lib": "folder-lib",
    "libs": "folder-lib",
    "library": "folder-lib",
    "libraries": "folder-lib",
    "vendor": "folder-lib",
    "vendors": "folder-lib",
    "third-party": "folder-lib",
    "themes": "folder-theme",
    "theme": "folder-theme",
    "color": "folder-theme",
    "colors": "folder-theme",
    "design": "folder-theme",
    "designs": "folder-theme",
    "webpack": "folder-webpack",
    ".webpack": "folder-webpack",
    "global": "folder-global",
    "public": "folder-public",
    "www": "folder-public",
    "wwwroot": "folder-public",
    "web": "folder-public",
    "website": "folder-public",
    "include": "folder-include",
    "includes": "folder-include",
    "_includes": "folder-include",
    "inc": "folder-include",
    "docker": "folder-docker",
    "dockerfiles": "folder-docker",
    ".docker": "folder-docker",
    "db": "folder-database",
    "database": "folder-database",
    "databases": "folder-database",
    "sql": "folder-database",
    "data": "folder-database",
    "_data": "folder-database",
    "log": "folder-log",
    "logs": "folder-log",
    "target": "folder-target",
    "temp": "folder-temp",
    ".temp": "folder-temp",
    "tmp": "folder-temp",
    ".tmp": "folder-temp",
    "cached": "folder-temp",
    "cache": "folder-temp",
    ".cache": "folder-temp",
    "aws": "folder-aws",
    ".aws": "folder-aws",
    "audio": "folder-audio",
    "audios": "folder-audio",
    "music": "folder-audio",
    "musics": "folder-audio",
    "sound": "folder-audio",
    "sounds": "folder-audio",
    "video": "folder-video",
    "videos": "folder-video",
    "movie": "folder-video",
    "movies": "folder-video",
    "kubernetes": "folder-kubernetes",
    "k8s": "folder-kubernetes",
    "import": "folder-import",
    "imports": "folder-import",
    "imported": "folder-import",
    "export": "folder-export",
    "exports": "folder-export",
    "exported": "folder-export",
    "wakatime": "folder-wakatime",
    ".circleci": "folder-circleci",
    ".wordpress-org": "folder-wordpress",
    "wp-content": "folder-wordpress",
    "gradle": "folder-gradle",
    ".gradle": "folder-gradle",
    "coverage": "folder-coverage",
    ".nyc-output": "folder-coverage",
    ".nyc_output": "folder-coverage",
    "e2e": "folder-coverage",
    "it": "folder-coverage",
    "integration-test": "folder-coverage",
    "integration-tests": "folder-coverage",
    "class": "folder-class",
    "classes": "folder-class",
    "model": "folder-class",
    "models": "folder-class",
    "schemas": "folder-class",
    "schema": "folder-class",
    "other": "folder-other",
    "others": "folder-other",
    "misc": "folder-other",
    "miscellaneous": "folder-other",
    "extra": "folder-other",
    "extras": "folder-other",
    "typescript": "folder-typescript",
    "ts": "folder-typescript",
    "typings": "folder-typescript",
    "@types": "folder-typescript",
    "types": "folder-typescript",
    "graphql": "folder-graphql",
    "gql": "folder-graphql",
    "routes": "folder-routes",
    "router": "folder-routes",
    "routers": "folder-routes",
    ".ci": "folder-ci",
    "ci": "folder-ci",
    "benchmark": "folder-benchmark",
    "benchmarks": "folder-benchmark",
    "performance": "folder-benchmark",
    "measure": "folder-benchmark",
    "measures": "folder-benchmark",
    "measurement": "folder-benchmark",
    "messages": "folder-messages",
    "messaging": "folder-messages",
    "forum": "folder-messages",
    "chat": "folder-messages",
    "chats": "folder-messages",
    "conversation": "folder-messages",
    "conversations": "folder-messages",
    "less": "folder-less",
    "gulp": "folder-gulp",
    "python": "folder-python",
    "__pycache__": "folder-python",
    ".pytest_cache": "folder-python",
    "debug": "folder-debug",
    "debugging": "folder-debug",
    "fastlane": "folder-fastlane",
    "plugin": "folder-plugin",
    "plugins": "folder-plugin",
    "_plugins": "folder-plugin",
    "extension": "folder-plugin",
    "extensions": "folder-plugin",
    "addon": "folder-plugin",
    "addons": "folder-plugin",
    "module": "folder-plugin",
    "modules": "folder-plugin",
    "middleware": "folder-middleware",
    "middlewares": "folder-middleware",
    "controller": "folder-controller",
    "controllers": "folder-controller",
    "service": "folder-controller",
    "services": "folder-controller",
    "provider": "folder-controller",
    "providers": "folder-controller",
    "handler": "folder-controller",
    "handlers": "folder-controller",
    "ansible": "folder-ansible",
    "server": "folder-server",
    "servers": "folder-server",
    "backend": "folder-server",
    "client": "folder-client",
    "clients": "folder-client",
    "frontend": "folder-client",
    "pwa": "folder-client",
    "tasks": "folder-tasks",
    "tickets": "folder-tasks",
    "android": "folder-android",
    "ios": "folder-ios",
    "uploads": "folder-upload",
    "upload": "folder-upload",
    "downloads": "folder-download",
    "download": "folder-download",
    "tools": "folder-tools",
    "helpers": "folder-helper",
    "helper": "folder-helper",
    ".serverless": "folder-serverless",
    "serverless": "folder-serverless",
    "api": "folder-api",
    "apis": "folder-api",
    "restapi": "folder-api",
    "app": "folder-app",
    "apps": "folder-app",
    "apollo": "folder-apollo",
    "apollo-client": "folder-apollo",
    "apollo-cache": "folder-apollo",
    "apollo-config": "folder-apollo",
    "archive": "folder-archive",
    "archives": "folder-archive",
    "archival": "folder-archive",
    "backup": "folder-archive",
    "backups": "folder-archive",
    "back-up": "folder-archive",
    "back-ups": "folder-archive",
    "batch": "folder-batch",
    "batchs": "folder-batch",
    "batches": "folder-batch",
    "cluster": "folder-cluster",
    "clusters": "folder-cluster",
    "command": "folder-command",
    "commands": "folder-command",
    "cmd": "folder-command",
    "cli": "folder-command",
    "clis": "folder-command",
    "constant": "folder-constant",
    "constants": "folder-constant",
    "container": "folder-container",
    "containers": "folder-container",
    ".devcontainer": "folder-container",
    "content": "folder-content",
    "contents": "folder-content",
    "context": "folder-context",
    "contexts": "folder-context",
    "core": "folder-core",
    "delta": "folder-delta",
    "deltas": "folder-delta",
    "changes": "folder-delta",
    "dump": "folder-dump",
    "dumps": "folder-dump",
    "demo": "folder-examples",
    "demos": "folder-examples",
    "example": "folder-examples",
    "examples": "folder-examples",
    "sample": "folder-examples",
    "samples": "folder-examples",
    "sample-data": "folder-examples",
    ".env": "folder-environment",
    ".environment": "folder-environment",
    "env": "folder-environment",
    "envs": "folder-environment",
    "environment": "folder-environment",
    "environments": "folder-environment",
    ".venv": "folder-environment",
    "function": "folder-functions",
    "functions": "folder-functions",
    "lambda": "folder-functions",
    "lambdas": "folder-functions",
    "logic": "folder-functions",
    "math": "folder-functions",
    "calc": "folder-functions",
    "calculation": "folder-functions",
    "calculations": "folder-functions",
    "generator": "folder-generator",
    "generators": "folder-generator",
    "generated": "folder-generator",
    "cfn-gen": "folder-generator",
    "gen": "folder-generator",
    "gens": "folder-generator",
    "auto": "folder-generator",
    "hook": "folder-hook",
    "hooks": "folder-hook",
    "trigger": "folder-hook",
    "triggers": "folder-hook",
    "job": "folder-job",
    "jobs": "folder-job",
    "keys": "folder-keys",
    "key": "folder-keys",
    "token": "folder-keys",
    "tokens": "folder-keys",
    "layout": "folder-layout",
    "layouts": "folder-layout",
    "mail": "folder-mail",
    "mails": "folder-mail",
    "email": "folder-mail",
    "emails": "folder-mail",
    "smtp": "folder-mail",
    "mailers": "folder-mail",
    "mappings": "folder-mappings",
    "mapping": "folder-mappings",
    "meta": "folder-meta",
    "package": "folder-packages",
    "packages": "folder-packages",
    "pkg": "folder-packages",
    "shared": "folder-shared",
    "common": "folder-shared",
    "stack": "folder-stack",
    "stacks": "folder-stack",
    "template": "folder-template",
    "templates": "folder-template",
    "util": "folder-utils",
    "utils": "folder-utils",
    "utility": "folder-utils",
    "utilities": "folder-utils",
    "private": "folder-private",
    ".private": "folder-private",
    "error": "folder-error",
    "errors": "folder-error",
    "err": "folder-error",
    "event": "folder-event",
    "events": "folder-event",
    "auth": "folder-secure",
    "authentication": "folder-secure",
    "secure": "folder-secure",
    "security": "folder-secure",
    "cert": "folder-secure",
    "certs": "folder-secure",
    "certificate": "folder-secure",
    "certificates": "folder-secure",
    "ssl": "folder-secure",
    "custom": "folder-custom",
    "customs": "folder-custom",
    "mock": "folder-mock",
    "mocks": "folder-mock",
    "draft": "folder-mock",
    "drafts": "folder-mock",
    "concept": "folder-mock",
    "concepts": "folder-mock",
    "sketch": "folder-mock",
    "sketches": "folder-mock",
    "syntax": "folder-syntax",
    "syntaxes": "folder-syntax",
    "spellcheck": "folder-syntax",
    "vm": "folder-vm",
    "vms": "folder-vm",
    "stylus": "folder-stylus",
    "flow-typed": "folder-flow",
    "rule": "folder-rules",
    "rules": "folder-rules",
    "validation": "folder-rules",
    "validations": "folder-rules",
    "validator": "folder-rules",
    "validators": "folder-rules",
    "review": "folder-review",
    "reviews": "folder-review",
    "revisal": "folder-review",
    "revisals": "folder-review",
    "reviewed": "folder-review",
    "animation": "folder-animation",
    "animations": "folder-animation",
    "animated": "folder-animation",
    "guard": "folder-guard",
    "guards": "folder-guard",
    "prisma": "folder-prisma",
    "pipe": "folder-pipe",
    "pipes": "folder-pipe",
    "svg": "folder-svg",
    "svgs": "folder-svg",
    "terraform": "folder-terraform",
    ".terraform": "folder-terraform",
    "mobile": "folder-mobile",
    "mobiles": "folder-mobile",
    "portable": "folder-mobile",
    "portability": "folder-mobile",
    ".stencil": "folder-stencil",
    ".firebase": "folder-firebase",
    "svelte": "folder-svelte",
    "update": "folder-update",
    "updates": "folder-update",
    "upgrade": "folder-update",
    "upgrades": "folder-update",
    ".idea": "folder-intellij",
    ".azure-pipelines": "folder-azure-pipelines",
    ".azure-pipelines-ci": "folder-azure-pipelines",
    "mjml": "folder-mjml",
    "admin": "folder-admin",
    "scala": "folder-scala",
    "connection": "folder-connection",
    "connections": "folder-connection",
    ".quasar": "folder-quasar",
    "cobol": "folder-cobol",
    "yarn": "folder-yarn",
    ".yarn": "folder-yarn",
    "husky": "folder-husky",
    ".husky": "folder-husky",
    ".storybook": "folder-storybook",
    "storybook": "folder-storybook",
    "stories": "folder-storybook",
    "__stories__": "folder-storybook",
    "base": "folder-base",
    ".base": "folder-base",
    "cart": "folder-cart",
    "shopping-cart": "folder-cart",
    "shopping": "folder-cart",
    "shop": "folder-cart",
    "home": "folder-home",
    ".home": "folder-home",
    "start": "folder-home",
    ".start": "folder-home",
    "project": "folder-project",
    "projects": "folder-project",
    ".project": "folder-project",
    ".projects": "folder-project",
    "interface": "folder-interface",
    "interfaces": "folder-interface",
    "pact": "folder-contract",
    "pacts": "folder-contract",
    "contract": "folder-contract",
    ".contract": "folder-contract",
    "contracts": "folder-contract",
    "contract-testing": "folder-contract",
    "contract-test": "folder-contract",
    "contract-tests": "folder-contract",
    "queue": "folder-queue",
    "queues": "folder-queue",
    "bull": "folder-queue",
    "mq": "folder-queue",
    "vercel": "folder-vercel",
    ".vercel": "folder-vercel",
    "now": "folder-vercel",
    ".now": "folder-vercel",
    "cypress": "folder-cypress",
    ".cypress": "folder-cypress",
    "java": "folder-java",
    "resolver": "folder-resolver",
    "resolvers": "folder-resolver",
    ".angular": "folder-angular"
};

class MonacoTreeContextMenuComponent {
    constructor(eRef) {
        this.eRef = eRef;
        this.elements = [];
    }
    clickout(event) {
        if (!this.eRef.nativeElement.contains(event.target)) {
            this.top = -1000;
            this.left = -1000;
        }
    }
}
MonacoTreeContextMenuComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MonacoTreeContextMenuComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
MonacoTreeContextMenuComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: MonacoTreeContextMenuComponent, selector: "monaco-tree-context-menu", inputs: { top: "top", left: "left", elements: "elements" }, host: { listeners: { "document:click": "clickout($event)" } }, ngImport: i0, template: "<div *ngIf=\"left && top\" class=\"monaco-tree-context-menu\" [style]=\"'top:' + top + 'px; left: ' + left + 'px'\">\n    <ul>\n        <li *ngFor=\"let element of elements\"\n\t\t\t[class]=\"element.type === 'element' ? 'monaco-tree-element' : 'monaco-tree-separator'\"\n\t\t\t(click)=\"element.type ==='element' ? element.action() : null\">\n\t\t\t<a *ngIf=\"element.type === 'element'\">{{element.name}}</a>\n\t\t</li>\n    </ul>\n</div>\n", styles: [".monaco-tree-context-menu{position:absolute;color:#f0f0f0;background-color:#3c3c3c;font-family:Roboto,sans-serif;font-size:.8em;font-weight:200}.monaco-tree-context-menu ul{padding:0;margin:0;list-style-type:none;min-width:150px}.monaco-tree-context-menu ul li{display:flex;align-items:center;height:2em;margin:10px 0}.monaco-tree-context-menu ul li.monaco-tree-element{padding:0 12px;cursor:pointer}.monaco-tree-context-menu ul li.monaco-tree-element:hover{background:rgb(9,71,133)}.monaco-tree-context-menu ul li.monaco-tree-separator{width:80%;margin:10px auto;height:1px;background:rgb(240,240,240)}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MonacoTreeContextMenuComponent, decorators: [{
            type: Component,
            args: [{ selector: 'monaco-tree-context-menu', template: "<div *ngIf=\"left && top\" class=\"monaco-tree-context-menu\" [style]=\"'top:' + top + 'px; left: ' + left + 'px'\">\n    <ul>\n        <li *ngFor=\"let element of elements\"\n\t\t\t[class]=\"element.type === 'element' ? 'monaco-tree-element' : 'monaco-tree-separator'\"\n\t\t\t(click)=\"element.type ==='element' ? element.action() : null\">\n\t\t\t<a *ngIf=\"element.type === 'element'\">{{element.name}}</a>\n\t\t</li>\n    </ul>\n</div>\n", styles: [".monaco-tree-context-menu{position:absolute;color:#f0f0f0;background-color:#3c3c3c;font-family:Roboto,sans-serif;font-size:.8em;font-weight:200}.monaco-tree-context-menu ul{padding:0;margin:0;list-style-type:none;min-width:150px}.monaco-tree-context-menu ul li{display:flex;align-items:center;height:2em;margin:10px 0}.monaco-tree-context-menu ul li.monaco-tree-element{padding:0 12px;cursor:pointer}.monaco-tree-context-menu ul li.monaco-tree-element:hover{background:rgb(9,71,133)}.monaco-tree-context-menu ul li.monaco-tree-separator{width:80%;margin:10px auto;height:1px;background:rgb(240,240,240)}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { top: [{
                type: Input
            }], left: [{
                type: Input
            }], elements: [{
                type: Input
            }], clickout: [{
                type: HostListener,
                args: ['document:click', ['$event']]
            }] } });

function getAbsolutePosition(element) {
    const r = { x: element.offsetLeft, y: element.offsetTop };
    if (element.offsetParent) {
        const tmp = getAbsolutePosition(element.offsetParent);
        r.x += tmp.x;
        r.y += tmp.y;
    }
    return r;
}
;
class MonacoTreeFileComponent {
    constructor(eRef) {
        this.eRef = eRef;
        this.name = '';
        this.content = undefined;
        this.depth = 0;
        this.theme = 'vs-dark';
        this.hide = false;
        this.clickFile = new EventEmitter();
        this.contextMenuClick = new EventEmitter();
        this.open = false;
        this.position = undefined;
        this.contextMenu = [
            { type: "element", name: 'New File', action: () => {
                    this.contextMenuClick.emit(["new_file", this.name]);
                    this.position = [-1000, -1000];
                } },
            { type: "element", name: 'New Directory', action: () => {
                    this.contextMenuClick.emit(["new_directory", this.name]);
                    this.position = [-1000, -1000];
                } },
            { type: "separator" },
            { type: "element", name: 'Rename', action: () => {
                    this.contextMenuClick.emit(["rename_file", this.name]);
                    this.position = [-1000, -1000];
                } },
            { type: "element", name: 'Delete', action: () => {
                    this.contextMenuClick.emit(["delete_file", this.name]);
                    this.position = [-1000, -1000];
                } }
        ];
    }
    get icon() {
        if (this.folder) {
            if (Object.keys(folders).includes(this.name)) {
                const icon = folders[this.name];
                if (this.open)
                    return icon + '-open';
                else
                    return icon;
            }
            else {
                if (this.open)
                    return 'folder-open';
                else
                    return 'folder';
            }
        }
        else {
            if (Object.keys(files).includes(this.name)) {
                return files[this.name];
            }
            else {
                let splited = this.name.split('.');
                while (splited.length > 0) {
                    splited = splited.slice(1);
                    const ext = splited.join('.');
                    if (ext && Object.keys(extensions).includes(ext)) {
                        return extensions[ext];
                    }
                }
                return 'file';
            }
        }
    }
    toggle() {
        this.open = !this.open;
        this.clickFile.emit(this.name);
    }
    get style() {
        return 'margin-left: ' + 10 * this.depth + 'px';
    }
    get folder() {
        return this.content !== null && this.content !== undefined;
    }
    handleClickFile(file) {
        this.clickFile.emit(this.name + '/' + file);
    }
    // handleRightClickFile(e: MouseEvent) {
    // 	e.preventDefault()
    // 	this.rightClickFile.emit(e);
    // }
    handleRightClickFile(event) {
        event.preventDefault();
        const pos = getAbsolutePosition(event.target);
        this.position = [pos.x + event.offsetX, pos.y + event.offsetY];
    }
    handleRightClick(event) {
        this.contextMenuClick.emit([event[0], this.name + '/' + event[1]]);
    }
    clickOut(event) {
        if (!this.eRef.nativeElement.contains(event.target)) {
            this.position = [-1000, -1000];
        }
    }
}
MonacoTreeFileComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MonacoTreeFileComponent, deps: [{ token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
MonacoTreeFileComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: MonacoTreeFileComponent, selector: "monaco-tree-file", inputs: { name: "name", content: "content", depth: "depth", theme: "theme", hide: "hide" }, outputs: { clickFile: "clickFile", contextMenuClick: "contextMenuClick" }, host: { listeners: { "document:contextmenu": "clickOut($event)" } }, ngImport: i0, template: "<div (contextmenu)=\"handleRightClickFile($event)\" (click)=\"toggle()\" [class]=\"'monaco-tree-row' + (hide ? ' hide ' : ' ') + theme\">\n    <span [style]=\"style\"></span>\n    <i *ngIf=\"folder\" [class]=\"'monaco-tree-arrow codicon codicon-chevron-down' + (open ? ' open' : '')\"></i>\n    <img [src]=\"'assets/icons/'+ icon +'.svg'\" class=\"monaco-tree-icon\"/>\n    <div class=\"monaco-tree-name\">{{name}}</div>\n</div>\n<monaco-tree-context-menu [elements]=\"contextMenu\" [top]=\"position ? position[1] : undefined\" [left]=\"position ? position[0] : undefined\"></monaco-tree-context-menu>\n<monaco-tree-file (contextMenuClick)=\"handleRightClick($event)\" (clickFile)=\"handleClickFile($event)\" *ngFor=\"let row of content\" [name]=\"row.name\" [content]=\"row.content\" [depth]=\"depth+1\" [hide]=\"!open || hide\" [theme]=\"theme\"></monaco-tree-file>\n", styles: [".monaco-tree-row{font-size:14px;line-height:24px;display:flex;gap:6px;cursor:pointer;padding-left:32px}.monaco-tree-row .monaco-tree-icon{width:16px;height:22px}.monaco-tree-row .monaco-tree-arrow{margin-left:-18px;width:12px;height:22px;line-height:22px;position:relative;top:2px;transform:rotate(-90deg);transition:all .5s}.monaco-tree-row .monaco-tree-arrow.open{transform:rotate(0);left:-2px;top:0}.monaco-tree-row.vs-dark:hover{background:#2a2d2e}.monaco-tree-row.vs-dark.active{background:rgb(63,63,70)}.monaco-tree-row.vs-light:hover{background:#e8e8e8}.monaco-tree-row.vs-light.active{background:#e4e6f1}.monaco-tree-row.hide{display:none}.monaco-tree-row.root-2 .monaco-tree-icon{margin-left:10px}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: MonacoTreeFileComponent, selector: "monaco-tree-file", inputs: ["name", "content", "depth", "theme", "hide"], outputs: ["clickFile", "contextMenuClick"] }, { kind: "component", type: MonacoTreeContextMenuComponent, selector: "monaco-tree-context-menu", inputs: ["top", "left", "elements"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: MonacoTreeFileComponent, decorators: [{
            type: Component,
            args: [{ selector: 'monaco-tree-file', template: "<div (contextmenu)=\"handleRightClickFile($event)\" (click)=\"toggle()\" [class]=\"'monaco-tree-row' + (hide ? ' hide ' : ' ') + theme\">\n    <span [style]=\"style\"></span>\n    <i *ngIf=\"folder\" [class]=\"'monaco-tree-arrow codicon codicon-chevron-down' + (open ? ' open' : '')\"></i>\n    <img [src]=\"'assets/icons/'+ icon +'.svg'\" class=\"monaco-tree-icon\"/>\n    <div class=\"monaco-tree-name\">{{name}}</div>\n</div>\n<monaco-tree-context-menu [elements]=\"contextMenu\" [top]=\"position ? position[1] : undefined\" [left]=\"position ? position[0] : undefined\"></monaco-tree-context-menu>\n<monaco-tree-file (contextMenuClick)=\"handleRightClick($event)\" (clickFile)=\"handleClickFile($event)\" *ngFor=\"let row of content\" [name]=\"row.name\" [content]=\"row.content\" [depth]=\"depth+1\" [hide]=\"!open || hide\" [theme]=\"theme\"></monaco-tree-file>\n", styles: [".monaco-tree-row{font-size:14px;line-height:24px;display:flex;gap:6px;cursor:pointer;padding-left:32px}.monaco-tree-row .monaco-tree-icon{width:16px;height:22px}.monaco-tree-row .monaco-tree-arrow{margin-left:-18px;width:12px;height:22px;line-height:22px;position:relative;top:2px;transform:rotate(-90deg);transition:all .5s}.monaco-tree-row .monaco-tree-arrow.open{transform:rotate(0);left:-2px;top:0}.monaco-tree-row.vs-dark:hover{background:#2a2d2e}.monaco-tree-row.vs-dark.active{background:rgb(63,63,70)}.monaco-tree-row.vs-light:hover{background:#e8e8e8}.monaco-tree-row.vs-light.active{background:#e4e6f1}.monaco-tree-row.hide{display:none}.monaco-tree-row.root-2 .monaco-tree-icon{margin-left:10px}\n"] }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }]; }, propDecorators: { name: [{
                type: Input
            }], content: [{
                type: Input
            }], depth: [{
                type: Input
            }], theme: [{
                type: Input
            }], hide: [{
                type: Input
            }], clickFile: [{
                type: Output
            }], contextMenuClick: [{
                type: Output
            }], clickOut: [{
                type: HostListener,
                args: ['document:contextmenu', ['$event']]
            }] } });

class NgxMonacoTreeComponent {
    constructor() {
        this.theme = 'vs-dark';
        this.tree = [];
        this.width = "300px";
        this.height = "500px";
        this.clickFile = new EventEmitter();
        this.clickContextMenu = new EventEmitter();
    }
    // @Output() contextMenuClick = new EventEmitter<ContextMenuAction>();
    // contextMenu: Array<ContextMenuElementSeparator|ContextMenuElementText> = [
    // 	{type: "element", name: 'New File', action: () => {
    // 		this.contextMenuClick.emit(["new_file", this.curr ?? ''])
    // 	} },
    // 	{type: "element", name: 'New Directory', action: () => {
    // 			this.contextMenuClick.emit(["new_directory", this.curr ?? ''])
    // 		} },
    // 	{type: "separator" },
    // 	{type: "element", name: 'Delete', action: () => {
    // 			this.contextMenuClick.emit(["delete_file", this.curr ?? ''])
    // 	} }
    // ]
    handleClickFile(path) {
        this.clickFile.emit(path);
    }
    handleClickContextMenu(event) {
        this.clickContextMenu.emit(event);
    }
}
NgxMonacoTreeComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NgxMonacoTreeComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
NgxMonacoTreeComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.12", type: NgxMonacoTreeComponent, selector: "monaco-tree", inputs: { theme: "theme", tree: "tree", width: "width", height: "height" }, outputs: { clickFile: "clickFile", clickContextMenu: "clickContextMenu" }, ngImport: i0, template: `
    <div [style]="'width:' + width + ';height:' + height" [class]="'monaco-tree ' + theme">
        <monaco-tree-file (contextMenuClick)="handleClickContextMenu($event)" (clickFile)="handleClickFile($event)" [theme]="theme" *ngFor="let row of tree" [name]="row.name" [content]="row.content" [depth]="0" [hide]="false"></monaco-tree-file>
    </div>
	`, isInline: true, styles: [".monaco-tree{font-family:-apple-system,BlinkMacSystemFont,Segoe WPC,Segoe UI,HelveticaNeue-dark,Ubuntu,Droid Sans,sans-serif;width:300px}.monaco-tree.vs-dark{background:#1d1d1d;color:#fff}.monaco-tree.vs-light{background:rgb(243,243,243);color:#616161}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "component", type: MonacoTreeFileComponent, selector: "monaco-tree-file", inputs: ["name", "content", "depth", "theme", "hide"], outputs: ["clickFile", "contextMenuClick"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NgxMonacoTreeComponent, decorators: [{
            type: Component,
            args: [{ selector: 'monaco-tree', template: `
    <div [style]="'width:' + width + ';height:' + height" [class]="'monaco-tree ' + theme">
        <monaco-tree-file (contextMenuClick)="handleClickContextMenu($event)" (clickFile)="handleClickFile($event)" [theme]="theme" *ngFor="let row of tree" [name]="row.name" [content]="row.content" [depth]="0" [hide]="false"></monaco-tree-file>
    </div>
	`, styles: [".monaco-tree{font-family:-apple-system,BlinkMacSystemFont,Segoe WPC,Segoe UI,HelveticaNeue-dark,Ubuntu,Droid Sans,sans-serif;width:300px}.monaco-tree.vs-dark{background:#1d1d1d;color:#fff}.monaco-tree.vs-light{background:rgb(243,243,243);color:#616161}\n"] }]
        }], propDecorators: { theme: [{
                type: Input
            }], tree: [{
                type: Input
            }], width: [{
                type: Input
            }], height: [{
                type: Input
            }], clickFile: [{
                type: Output
            }], clickContextMenu: [{
                type: Output
            }] } });

class NgxMonacoTreeModule {
}
NgxMonacoTreeModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NgxMonacoTreeModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxMonacoTreeModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.12", ngImport: i0, type: NgxMonacoTreeModule, declarations: [NgxMonacoTreeComponent,
        MonacoTreeFileComponent,
        MonacoTreeContextMenuComponent], imports: [BrowserModule], exports: [NgxMonacoTreeComponent] });
NgxMonacoTreeModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NgxMonacoTreeModule, imports: [BrowserModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.12", ngImport: i0, type: NgxMonacoTreeModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxMonacoTreeComponent,
                        MonacoTreeFileComponent,
                        MonacoTreeContextMenuComponent,
                    ],
                    imports: [
                        BrowserModule,
                    ],
                    exports: [
                        NgxMonacoTreeComponent
                    ]
                }]
        }] });

/*
 * Public API Surface of ngx-monaco-tree
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxMonacoTreeComponent, NgxMonacoTreeModule };
//# sourceMappingURL=ngx-monaco-tree.mjs.map
